==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/attentionplugin/.rcc/qrc_attentionplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/attentionplugin/attention.png
  0x0,0x0,0x3,0xa7,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xfe,0x0,0xfe,0x0,0xfe,0xeb,0x18,
  0xd4,0x82,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x0,0x9,0x76,0x70,0x41,0x67,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x0,0x5c,0xc6,0xad,0xc3,0x0,0x0,0x2,0xd0,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x55,0x93,0x4f,0x68,0x53,0x59,0x14,0xc6,0x7f,0xf7,
  0xbe,0xfb,0x5e,0x12,0xa3,0x31,0x35,0xb5,0xd6,0x7f,0x1d,0xaa,0xe0,0x98,0x38,0x51,
  0x64,0x60,0xac,0x14,0x6d,0x53,0x74,0x61,0x14,0x46,0x37,0x82,0xe,0x22,0xb3,0xd0,
  0x85,0x56,0x51,0x14,0xb4,0xba,0xd0,0x85,0x20,0x3,0xb3,0xd4,0x95,0xc8,0x2c,0x46,
  0xcc,0x5a,0xb0,0x5,0x57,0x8a,0x5a,0xb5,0x88,0xf8,0xaf,0x8d,0x33,0x1b,0xa9,0x50,
  0xa3,0xed,0x34,0xb1,0xb6,0x69,0xfe,0xbe,0x77,0xaf,0x9b,0x17,0xc9,0x5c,0xb8,0xdc,
  0xc3,0xb9,0xe7,0x3b,0x7c,0xf7,0xfb,0xce,0x15,0xf8,0x2b,0x95,0x4a,0x59,0x7e,0x28,
  0x84,0x10,0x96,0xd6,0xba,0xde,0xb5,0xe2,0xc1,0x9f,0x0,0xcf,0x72,0xbd,0x67,0xfd,
  0x3b,0xb,0xd0,0x80,0xf1,0xb,0x95,0x68,0x80,0x7f,0xdb,0x9d,0xf8,0xc3,0xd3,0x66,
  0x5f,0x66,0x28,0xfb,0xe3,0xd1,0xed,0x4f,0xd2,0x61,0xa7,0x76,0x5,0x48,0x3e,0xcd,
  0x2,0x30,0x1a,0xef,0xc,0x5d,0xfa,0x6b,0x78,0xcb,0xe0,0x81,0x5d,0xf1,0x29,0xcb,
  0x92,0x37,0x6e,0xdd,0x1d,0x3b,0xf,0x20,0x52,0xa9,0x94,0x73,0x30,0x9d,0xb8,0xaa,
  0x8d,0xd9,0x9b,0x19,0xca,0x26,0x80,0x85,0xa7,0x77,0x3c,0xb8,0xbf,0xa6,0xfb,0x42,
  0xb2,0x23,0x2e,0x1,0xc8,0xdc,0xfc,0xc0,0xf8,0xd8,0xdf,0x3c,0xcb,0xf5,0xb6,0x0,
  0xf5,0x3,0xe9,0xc4,0x17,0x21,0xc4,0xb5,0xdb,0x83,0x63,0x3,0x52,0x8,0x81,0x6d,
  0xcb,0x63,0x99,0xa1,0xec,0x4f,0x40,0xf4,0xf7,0xee,0x91,0x9e,0xf6,0x75,0x3b,0x93,
  0x1d,0x71,0x49,0x64,0x99,0x66,0x7a,0x2,0x22,0xd1,0x56,0xc2,0x2d,0x9,0x36,0xb5,
  0x3d,0xbf,0x8,0x4,0x32,0x43,0xd9,0x25,0x96,0x14,0xfd,0x40,0x48,0x2,0xca,0xb1,
  0x55,0x10,0x88,0x2,0xe5,0x68,0xa8,0x7c,0x39,0xf6,0x43,0x17,0x91,0x65,0x9a,0xdc,
  0x3b,0x45,0x69,0x4e,0x3,0x98,0xd0,0xa2,0x35,0x4,0x55,0x29,0xd,0xd8,0x80,0xc,
  0x5,0x6d,0x1b,0x68,0x93,0x80,0xf2,0x5,0x92,0xfe,0x4e,0x36,0x84,0x2d,0xcf,0x19,
  0xaa,0x15,0xd,0x40,0x60,0xc1,0x72,0x4,0x26,0x1,0x44,0xfc,0x3a,0x0,0x47,0x2,
  0x54,0x6b,0x6e,0x7f,0xc3,0x81,0x6,0x18,0x13,0x0,0xa0,0x56,0x35,0xff,0xcf,0x43,
  0x10,0x50,0x95,0xaa,0x7b,0xa,0xc0,0xea,0xec,0xec,0x94,0xaf,0xfe,0x99,0x7c,0x9,
  0xa8,0xfe,0xd4,0xa3,0x33,0x2b,0xd7,0xef,0xd8,0xb6,0x20,0xba,0xa,0x27,0x6c,0x98,
  0x2f,0xc0,0x7c,0xd1,0x63,0x66,0xce,0x33,0xe5,0x72,0x4d,0x14,0x2b,0x92,0xa5,0xea,
  0x85,0xfb,0x79,0x7e,0xf5,0xf0,0xeb,0x7f,0xa7,0x5e,0x2,0x4a,0x2,0x2e,0xe0,0x9d,
  0xec,0x7b,0x78,0xd2,0xb6,0xbc,0x81,0xb5,0x1b,0xba,0x58,0xfb,0x8b,0xc0,0x54,0xc,
  0x0,0xa5,0x39,0xef,0x3b,0x83,0x48,0xeb,0x46,0x2,0x56,0xf5,0xc4,0xcf,0xed,0xc3,
  0x67,0xfd,0x67,0xe4,0xa5,0xd6,0xda,0x1c,0xef,0x7d,0xbc,0xd3,0x92,0xfa,0x62,0xf7,
  0xfe,0x1,0x13,0x4b,0x28,0xdc,0x3c,0xcc,0x8c,0x1b,0x8a,0x5f,0x8d,0x9,0x2f,0x52,
  0x34,0x6,0x7,0x20,0xbc,0xea,0x30,0xb6,0xac,0x9f,0x59,0x1f,0x7b,0xf3,0x2b,0xa0,
  0x15,0x80,0xa3,0xdc,0xab,0xdd,0x87,0x2e,0x10,0xeb,0x58,0x58,0x7,0x81,0x8a,0xcd,
  0x38,0xab,0xb7,0x42,0xcb,0x97,0x80,0x28,0x8c,0xe6,0x10,0xa5,0x92,0x68,0xd,0x19,
  0xca,0x55,0x97,0x4f,0xd3,0xae,0x99,0xb4,0x7b,0x58,0xcc,0xc3,0xd3,0xc0,0x60,0xc3,
  0x81,0x64,0xac,0xbd,0x64,0x98,0xad,0x39,0xcc,0x6,0xa9,0x7c,0x85,0xff,0x66,0x6d,
  0xa,0x45,0xcd,0xf4,0x64,0x1b,0x53,0xb3,0x1e,0xf9,0x7c,0x91,0x62,0xc5,0xc3,0x75,
  0x3d,0xe1,0x84,0x6c,0x44,0xdd,0x6c,0x0,0xda,0x14,0xc0,0x93,0xac,0xd8,0xfd,0xe8,
  0xf0,0xf5,0xb4,0x41,0x28,0x63,0x44,0x43,0x71,0x91,0xde,0x73,0xe2,0xc8,0xdb,0xd1,
  0x7b,0xe3,0xef,0x27,0x74,0xc1,0x8,0x2b,0xd8,0xe4,0x4,0xf9,0x7a,0xd7,0x35,0xc0,
  0x56,0x0,0x23,0xb9,0x9e,0xfb,0xc0,0xb,0xc0,0x69,0xf2,0x78,0xc9,0xf1,0x78,0xf0,
  0xc8,0xc7,0x89,0x60,0xfb,0x9d,0x91,0xf0,0x39,0x20,0xeb,0xb,0xde,0xd0,0xc3,0x0,
  0x5a,0xf4,0xf5,0xf5,0xd9,0x40,0x40,0x6b,0x5d,0xf7,0xc1,0xdf,0x19,0x0,0x9b,0x81,
  0xa5,0x40,0x1,0x18,0x3,0xea,0x4d,0x24,0xc,0x80,0xd2,0x5a,0xbb,0xfe,0x17,0x15,
  0x80,0xe7,0x9f,0xc6,0xcf,0x3d,0x6f,0x9a,0x54,0xcf,0x6f,0x60,0x9a,0x9a,0xf0,0xd,
  0xf3,0xfd,0xe,0xf4,0x65,0x7c,0x14,0x6c,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,
  0x63,0x72,0x65,0x61,0x74,0x65,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,0x30,
  0x2d,0x30,0x31,0x2d,0x31,0x31,0x54,0x30,0x39,0x3a,0x32,0x35,0x3a,0x31,0x32,0x2b,
  0x30,0x32,0x3a,0x30,0x30,0x2f,0x82,0x3f,0xd1,0x0,0x0,0x0,0x25,0x74,0x45,0x58,
  0x74,0x6d,0x6f,0x64,0x69,0x66,0x79,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,
  0x30,0x2d,0x30,0x31,0x2d,0x31,0x31,0x54,0x30,0x39,0x3a,0x32,0x35,0x3a,0x31,0x32,
  0x2b,0x30,0x32,0x3a,0x30,0x30,0x70,0x33,0x49,0xe5,0x0,0x0,0x0,0x0,0x49,0x45,
  0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // attentionplugin
  0x0,0xf,
  0x0,0xf8,0xbf,0x5e,
  0x0,0x61,
  0x0,0x74,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,0x0,0x6e,
    // attention.png
  0x0,0xd,
  0x1,0x54,0xdc,0x47,
  0x0,0x61,
  0x0,0x74,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/attentionplugin
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/attentionplugin/attention.png
  0x0,0x0,0x0,0x24,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_attentionplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_attentionplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_attentionplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_attentionplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_attentionplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_attentionplugin)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/attentionplugin/.rcc/qrc_attentionplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/attentionplugin/attention.png
  0x0,0x0,0x3,0xa7,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xfe,0x0,0xfe,0x0,0xfe,0xeb,0x18,
  0xd4,0x82,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x0,0x9,0x76,0x70,0x41,0x67,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x0,0x5c,0xc6,0xad,0xc3,0x0,0x0,0x2,0xd0,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x55,0x93,0x4f,0x68,0x53,0x59,0x14,0xc6,0x7f,0xf7,
  0xbe,0xfb,0x5e,0x12,0xa3,0x31,0x35,0xb5,0xd6,0x7f,0x1d,0xaa,0xe0,0x98,0x38,0x51,
  0x64,0x60,0xac,0x14,0x6d,0x53,0x74,0x61,0x14,0x46,0x37,0x82,0xe,0x22,0xb3,0xd0,
  0x85,0x56,0x51,0x14,0xb4,0xba,0xd0,0x85,0x20,0x3,0xb3,0xd4,0x95,0xc8,0x2c,0x46,
  0xcc,0x5a,0xb0,0x5,0x57,0x8a,0x5a,0xb5,0x88,0xf8,0xaf,0x8d,0x33,0x1b,0xa9,0x50,
  0xa3,0xed,0x34,0xb1,0xb6,0x69,0xfe,0xbe,0x77,0xaf,0x9b,0x17,0xc9,0x5c,0xb8,0xdc,
  0xc3,0xb9,0xe7,0x3b,0x7c,0xf7,0xfb,0xce,0x15,0xf8,0x2b,0x95,0x4a,0x59,0x7e,0x28,
  0x84,0x10,0x96,0xd6,0xba,0xde,0xb5,0xe2,0xc1,0x9f,0x0,0xcf,0x72,0xbd,0x67,0xfd,
  0x3b,0xb,0xd0,0x80,0xf1,0xb,0x95,0x68,0x80,0x7f,0xdb,0x9d,0xf8,0xc3,0xd3,0x66,
  0x5f,0x66,0x28,0xfb,0xe3,0xd1,0xed,0x4f,0xd2,0x61,0xa7,0x76,0x5,0x48,0x3e,0xcd,
  0x2,0x30,0x1a,0xef,0xc,0x5d,0xfa,0x6b,0x78,0xcb,0xe0,0x81,0x5d,0xf1,0x29,0xcb,
  0x92,0x37,0x6e,0xdd,0x1d,0x3b,0xf,0x20,0x52,0xa9,0x94,0x73,0x30,0x9d,0xb8,0xaa,
  0x8d,0xd9,0x9b,0x19,0xca,0x26,0x80,0x85,0xa7,0x77,0x3c,0xb8,0xbf,0xa6,0xfb,0x42,
  0xb2,0x23,0x2e,0x1,0xc8,0xdc,0xfc,0xc0,0xf8,0xd8,0xdf,0x3c,0xcb,0xf5,0xb6,0x0,
  0xf5,0x3,0xe9,0xc4,0x17,0x21,0xc4,0xb5,0xdb,0x83,0x63,0x3,0x52,0x8,0x81,0x6d,
  0xcb,0x63,0x99,0xa1,0xec,0x4f,0x40,0xf4,0xf7,0xee,0x91,0x9e,0xf6,0x75,0x3b,0x93,
  0x1d,0x71,0x49,0x64,0x99,0x66,0x7a,0x2,0x22,0xd1,0x56,0xc2,0x2d,0x9,0x36,0xb5,
  0x3d,0xbf,0x8,0x4,0x32,0x43,0xd9,0x25,0x96,0x14,0xfd,0x40,0x48,0x2,0xca,0xb1,
  0x55,0x10,0x88,0x2,0xe5,0x68,0xa8,0x7c,0x39,0xf6,0x43,0x17,0x91,0x65,0x9a,0xdc,
  0x3b,0x45,0x69,0x4e,0x3,0x98,0xd0,0xa2,0x35,0x4,0x55,0x29,0xd,0xd8,0x80,0xc,
  0x5,0x6d,0x1b,0x68,0x93,0x80,0xf2,0x5,0x92,0xfe,0x4e,0x36,0x84,0x2d,0xcf,0x19,
  0xaa,0x15,0xd,0x40,0x60,0xc1,0x72,0x4,0x26,0x1,0x44,0xfc,0x3a,0x0,0x47,0x2,
  0x54,0x6b,0x6e,0x7f,0xc3,0x81,0x6,0x18,0x13,0x0,0xa0,0x56,0x35,0xff,0xcf,0x43,
  0x10,0x50,0x95,0xaa,0x7b,0xa,0xc0,0xea,0xec,0xec,0x94,0xaf,0xfe,0x99,0x7c,0x9,
  0xa8,0xfe,0xd4,0xa3,0x33,0x2b,0xd7,0xef,0xd8,0xb6,0x20,0xba,0xa,0x27,0x6c,0x98,
  0x2f,0xc0,0x7c,0xd1,0x63,0x66,0xce,0x33,0xe5,0x72,0x4d,0x14,0x2b,0x92,0xa5,0xea,
  0x85,0xfb,0x79,0x7e,0xf5,0xf0,0xeb,0x7f,0xa7,0x5e,0x2,0x4a,0x2,0x2e,0xe0,0x9d,
  0xec,0x7b,0x78,0xd2,0xb6,0xbc,0x81,0xb5,0x1b,0xba,0x58,0xfb,0x8b,0xc0,0x54,0xc,
  0x0,0xa5,0x39,0xef,0x3b,0x83,0x48,0xeb,0x46,0x2,0x56,0xf5,0xc4,0xcf,0xed,0xc3,
  0x67,0xfd,0x67,0xe4,0xa5,0xd6,0xda,0x1c,0xef,0x7d,0xbc,0xd3,0x92,0xfa,0x62,0xf7,
  0xfe,0x1,0x13,0x4b,0x28,0xdc,0x3c,0xcc,0x8c,0x1b,0x8a,0x5f,0x8d,0x9,0x2f,0x52,
  0x34,0x6,0x7,0x20,0xbc,0xea,0x30,0xb6,0xac,0x9f,0x59,0x1f,0x7b,0xf3,0x2b,0xa0,
  0x15,0x80,0xa3,0xdc,0xab,0xdd,0x87,0x2e,0x10,0xeb,0x58,0x58,0x7,0x81,0x8a,0xcd,
  0x38,0xab,0xb7,0x42,0xcb,0x97,0x80,0x28,0x8c,0xe6,0x10,0xa5,0x92,0x68,0xd,0x19,
  0xca,0x55,0x97,0x4f,0xd3,0xae,0x99,0xb4,0x7b,0x58,0xcc,0xc3,0xd3,0xc0,0x60,0xc3,
  0x81,0x64,0xac,0xbd,0x64,0x98,0xad,0x39,0xcc,0x6,0xa9,0x7c,0x85,0xff,0x66,0x6d,
  0xa,0x45,0xcd,0xf4,0x64,0x1b,0x53,0xb3,0x1e,0xf9,0x7c,0x91,0x62,0xc5,0xc3,0x75,
  0x3d,0xe1,0x84,0x6c,0x44,0xdd,0x6c,0x0,0xda,0x14,0xc0,0x93,0xac,0xd8,0xfd,0xe8,
  0xf0,0xf5,0xb4,0x41,0x28,0x63,0x44,0x43,0x71,0x91,0xde,0x73,0xe2,0xc8,0xdb,0xd1,
  0x7b,0xe3,0xef,0x27,0x74,0xc1,0x8,0x2b,0xd8,0xe4,0x4,0xf9,0x7a,0xd7,0x35,0xc0,
  0x56,0x0,0x23,0xb9,0x9e,0xfb,0xc0,0xb,0xc0,0x69,0xf2,0x78,0xc9,0xf1,0x78,0xf0,
  0xc8,0xc7,0x89,0x60,0xfb,0x9d,0x91,0xf0,0x39,0x20,0xeb,0xb,0xde,0xd0,0xc3,0x0,
  0x5a,0xf4,0xf5,0xf5,0xd9,0x40,0x40,0x6b,0x5d,0xf7,0xc1,0xdf,0x19,0x0,0x9b,0x81,
  0xa5,0x40,0x1,0x18,0x3,0xea,0x4d,0x24,0xc,0x80,0xd2,0x5a,0xbb,0xfe,0x17,0x15,
  0x80,0xe7,0x9f,0xc6,0xcf,0x3d,0x6f,0x9a,0x54,0xcf,0x6f,0x60,0x9a,0x9a,0xf0,0xd,
  0xf3,0xfd,0xe,0xf4,0x65,0x7c,0x14,0x6c,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,
  0x63,0x72,0x65,0x61,0x74,0x65,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,0x30,
  0x2d,0x30,0x31,0x2d,0x31,0x31,0x54,0x30,0x39,0x3a,0x32,0x35,0x3a,0x31,0x32,0x2b,
  0x30,0x32,0x3a,0x30,0x30,0x2f,0x82,0x3f,0xd1,0x0,0x0,0x0,0x25,0x74,0x45,0x58,
  0x74,0x6d,0x6f,0x64,0x69,0x66,0x79,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,
  0x30,0x2d,0x30,0x31,0x2d,0x31,0x31,0x54,0x30,0x39,0x3a,0x32,0x35,0x3a,0x31,0x32,
  0x2b,0x30,0x32,0x3a,0x30,0x30,0x70,0x33,0x49,0xe5,0x0,0x0,0x0,0x0,0x49,0x45,
  0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // attentionplugin
  0x0,0xf,
  0x0,0xf8,0xbf,0x5e,
  0x0,0x61,
  0x0,0x74,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,0x0,0x6e,
    // attention.png
  0x0,0xd,
  0x1,0x54,0xdc,0x47,
  0x0,0x61,
  0x0,0x74,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,
  // :/attentionplugin
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,
  // :/attentionplugin/attention.png
  0x0,0x0,0x0,0x24,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_attentionplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_attentionplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_attentionplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_attentionplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_attentionplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_attentionplugin)(); }
   } dummy;
}
